<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\FactoryRequest;
use App\Http\Resources\FactoryResource;
use App\Models\Factory;
use Illuminate\Http\JsonResponse;

class FactoryController extends Controller
{
    /**
     * Display a listing of the factories.
     */
    public function index(): JsonResponse {
        $factories = $this->paginateOrGet(Factory::filter()->latest());

        return $this->respondWithResourceCollection(
            FactoryResource::collection($factories)
        );
    }

    /**
     * Store a newly created factory in storage.
     */
    public function store(FactoryRequest $request): JsonResponse {
        $factory = Factory::create($request->validated());

        return $this->respondCreated(
            new FactoryResource($factory),
            "Factory created successfully!"
        );
    }

    /**
     * Display the specified factory.
     */
    public function show(Factory $factory): JsonResponse {
        // $factory->loadMissing($this->relations);

        return $this->respondWithResource(new FactoryResource($factory));
    }

    /**
     * Update the specified factory in storage.
     */
    public function update(FactoryRequest $request, Factory $factory): JsonResponse {
        $factory->update($request->validated());

        return $this->respondUpdated(
            new FactoryResource($factory),
            "Factory updated successfully!"
        );
    }

    /**
     * Remove the specified factory from storage.
     */
    public function destroy(Factory $factory): JsonResponse {
        $factory->delete();

        return $this->respondSuccess("Factory deleted successfully!");
    }
}
