<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\ItemRequest;
use App\Http\Resources\ItemResource;
use App\Models\Item;
use Illuminate\Http\JsonResponse;

class ItemController extends Controller
{
    protected array $relations = [
        "factoryRelation", "shop"
    ];

    /**
     * Display a listing of the items.
     */
    public function index(): JsonResponse {
        $items = $this->paginateOrGet(
            Item::with($this->getRelations())->filter()->latest());

        return $this->respondWithResourceCollection(
            ItemResource::collection($items)
        );
    }

    /**
     * Store a newly created item in storage.
     */
    public function store(ItemRequest $request): JsonResponse {
        $item = Item::create($request->validated());

        return $this->respondCreated(
            new ItemResource($item),
            "Item created successfully!"
        );
    }

    /**
     * Display the specified item.
     */
    public function show(Item $item): JsonResponse {
        $item->loadMissing($this->getRelations());

        return $this->respondWithResource(new ItemResource($item));
    }

    /**
     * Update the specified item in storage.
     */
    public function update(ItemRequest $request, Item $item): JsonResponse {
        $item->update($request->validated());

        return $this->respondUpdated(
            new ItemResource($item),
            "Item updated successfully!"
        );
    }

    /**
     * Remove the specified item from storage.
     */
    public function destroy(Item $item): JsonResponse {
        $item->delete();

        return $this->respondSuccess("Item deleted successfully!");
    }
}
