<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\JobCardUpdateRequest;
use App\Http\Resources\JobCardUpdateResource;
use App\Models\JobCardUpdate;
use Illuminate\Http\JsonResponse;

class JobCardUpdateController extends Controller
{
    protected array $relations = [
        "jobCard", "item",
    ];

    /**
     * Display a listing of the jobCardUpdates.
     */
    public function index(): JsonResponse {
        $jobCardUpdates = $this->paginateOrGet(
            JobCardUpdate::with($this->getRelations())->latest());

        return $this->respondWithResourceCollection(
            JobCardUpdateResource::collection($jobCardUpdates)
        );
    }

    /**
     * Store a newly created jobCardUpdate in storage.
     */
    public function store(JobCardUpdateRequest $request): JsonResponse {
        $jobCardUpdate = JobCardUpdate::create($request->validated());

        return $this->respondCreated(
            new JobCardUpdateResource($jobCardUpdate),
            "JobCardUpdate created successfully!"
        );
    }

    /**
     * Display the specified jobCardUpdate.
     */
    public function show(JobCardUpdate $jobCardUpdate): JsonResponse {
        $jobCardUpdate->loadMissing($this->getRelations());

        return $this->respondWithResource(new JobCardUpdateResource($jobCardUpdate));
    }

    /**
     * Update the specified jobCardUpdate in storage.
     */
    public function update(JobCardUpdateRequest $request, JobCardUpdate $jobCardUpdate): JsonResponse {
        $jobCardUpdate->update($request->validated());

        return $this->respondUpdated(
            new JobCardUpdateResource($jobCardUpdate),
            "JobCardUpdate updated successfully!"
        );
    }

    /**
     * Remove the specified jobCardUpdate from storage.
     */
    public function destroy(JobCardUpdate $jobCardUpdate): JsonResponse {
        $jobCardUpdate->delete();

        return $this->respondSuccess("JobCardUpdate deleted successfully!");
    }
}
