<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\OutsourcedJobRequest;
use App\Http\Resources\OutsourcedJobResource;
use App\Models\OutsourcedJob;
use Illuminate\Http\JsonResponse;

class OutsourcedJobController extends Controller
{
    protected array $relations = [
        "vendor", "jobCard"
    ];

    /**
     * Display a listing of the outsourcedJobs.
     */
    public function index(): JsonResponse {
        $outsourcedJobs = $this->paginateOrGet(
            OutsourcedJob::with($this->getRelations())->filter()->latest());

        return $this->respondWithResourceCollection(
            OutsourcedJobResource::collection($outsourcedJobs)
        );
    }

    /**
     * Store a newly created outsourcedJob in storage.
     */
    public function store(OutsourcedJobRequest $request): JsonResponse {
        $outsourcedJob = OutsourcedJob::create($request->validated());

        return $this->respondCreated(
            new OutsourcedJobResource($outsourcedJob),
            "OutsourcedJob created successfully!"
        );
    }

    /**
     * Display the specified outsourcedJob.
     */
    public function show(OutsourcedJob $outsourcedJob): JsonResponse {
        $outsourcedJob->loadMissing($this->getRelations());

        return $this->respondWithResource(new OutsourcedJobResource($outsourcedJob));
    }

    /**
     * Update the specified outsourcedJob in storage.
     */
    public function update(OutsourcedJobRequest $request, OutsourcedJob $outsourcedJob): JsonResponse {
        $outsourcedJob->update($request->validated());

        return $this->respondUpdated(
            new OutsourcedJobResource($outsourcedJob),
            "OutsourcedJob updated successfully!"
        );
    }

    /**
     * Remove the specified outsourcedJob from storage.
     */
    public function destroy(OutsourcedJob $outsourcedJob): JsonResponse {
        $outsourcedJob->delete();

        return $this->respondSuccess("OutsourcedJob deleted successfully!");
    }
}
