<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\PaymentRequest;
use App\Http\Resources\PaymentResource;
use App\Models\Payment;
use Illuminate\Http\JsonResponse;

class PaymentController extends Controller
{
    protected array $relations = [
        "bill"
    ];

    /**
     * Display a listing of the payments.
     */
    public function index(): JsonResponse {
        $payments = $this->paginateOrGet(
            Payment::with($this->getRelations())->filter()->latest());

        return $this->respondWithResourceCollection(
            PaymentResource::collection($payments)
        );
    }

    /**
     * Store a newly created payment in storage.
     */
    public function store(PaymentRequest $request): JsonResponse {
        $payment = Payment::create($request->validated());

        return $this->respondCreated(
            new PaymentResource($payment),
            "Payment created successfully!"
        );
    }

    /**
     * Display the specified payment.
     */
    public function show(Payment $payment): JsonResponse {
        $payment->loadMissing($this->getRelations());

        return $this->respondWithResource(new PaymentResource($payment));
    }

    /**
     * Update the specified payment in storage.
     */
    public function update(PaymentRequest $request, Payment $payment): JsonResponse {
        $payment->update($request->validated());

        return $this->respondUpdated(
            new PaymentResource($payment),
            "Payment updated successfully!"
        );
    }

    /**
     * Remove the specified payment from storage.
     */
    public function destroy(Payment $payment): JsonResponse {
        $payment->delete();

        return $this->respondSuccess("Payment deleted successfully!");
    }
}
