<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\SaleOrderRequest;
use App\Http\Resources\SaleOrderResource;
use App\Models\SaleOrder;
use Illuminate\Http\JsonResponse;

class SaleOrderController extends Controller
{
    protected array $relations = [
        "purchaseOrder", "bill"
    ];

    /**
     * Display a listing of the saleOrders.
     */
    public function index(): JsonResponse {
        $saleOrders = $this->paginateOrGet(
            SaleOrder::with($this->getRelations())->filter()->latest());

        return $this->respondWithResourceCollection(
            SaleOrderResource::collection($saleOrders)
        );
    }

    /**
     * Store a newly created saleOrder in storage.
     */
    public function store(SaleOrderRequest $request): JsonResponse {
        $saleOrder = SaleOrder::create($request->validated());

        return $this->respondCreated(
            new SaleOrderResource($saleOrder),
            "SaleOrder created successfully!"
        );
    }

    /**
     * Display the specified saleOrder.
     */
    public function show(SaleOrder $saleOrder): JsonResponse {
        $saleOrder->loadMissing($this->getRelations());

        return $this->respondWithResource(new SaleOrderResource($saleOrder));
    }

    /**
     * Update the specified saleOrder in storage.
     */
    public function update(SaleOrderRequest $request, SaleOrder $saleOrder): JsonResponse {
        $saleOrder->update($request->validated());

        return $this->respondUpdated(
            new SaleOrderResource($saleOrder),
            "SaleOrder updated successfully!"
        );
    }

    /**
     * Remove the specified saleOrder from storage.
     */
    public function destroy(SaleOrder $saleOrder): JsonResponse {
        $saleOrder->delete();

        return $this->respondSuccess("SaleOrder deleted successfully!");
    }
}
