<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\ShopRequest;
use App\Http\Resources\ShopResource;
use App\Models\Shop;
use Illuminate\Http\JsonResponse;

class ShopController extends Controller
{
    /**
     * Display a listing of the shops.
     */
    public function index(): JsonResponse {
        $shops = $this->paginateOrGet(Shop::filter()->latest());

        return $this->respondWithResourceCollection(
            ShopResource::collection($shops)
        );
    }

    /**
     * Store a newly created shop in storage.
     */
    public function store(ShopRequest $request): JsonResponse {
        $shop = Shop::create($request->validated());

        return $this->respondCreated(
            new ShopResource($shop),
            "Shop created successfully!"
        );
    }

    /**
     * Display the specified shop.
     */
    public function show(Shop $shop): JsonResponse {
        // $shop->loadMissing($this->relations);

        return $this->respondWithResource(new ShopResource($shop));
    }

    /**
     * Update the specified shop in storage.
     */
    public function update(ShopRequest $request, Shop $shop): JsonResponse {
        $shop->update($request->validated());

        return $this->respondUpdated(
            new ShopResource($shop),
            "Shop updated successfully!"
        );
    }

    /**
     * Remove the specified shop from storage.
     */
    public function destroy(Shop $shop): JsonResponse {
        $shop->delete();

        return $this->respondSuccess("Shop deleted successfully!");
    }
}
