<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\VendorRequest;
use App\Http\Resources\VendorResource;
use App\Models\Vendor;
use Illuminate\Http\JsonResponse;

class VendorController extends Controller
{
    protected array $relations = [
        "supplies"
    ];

    /**
     * Display a listing of the vendors.
     */
    public function index(): JsonResponse {
        $vendors = $this->paginateOrGet(
            Vendor::with($this->getRelations())->filter()->latest());

        return $this->respondWithResourceCollection(
            VendorResource::collection($vendors)
        );
    }

    /**
     * Store a newly created vendor in storage.
     */
    public function store(VendorRequest $request): JsonResponse {
        $vendor = Vendor::create($request->validated());

        return $this->respondCreated(
            new VendorResource($vendor),
            "Vendor created successfully!"
        );
    }

    /**
     * Display the specified vendor.
     */
    public function show(Vendor $vendor): JsonResponse {
        $vendor->loadMissing($this->relations);

        return $this->respondWithResource(new VendorResource($vendor));
    }

    /**
     * Update the specified vendor in storage.
     */
    public function update(VendorRequest $request, Vendor $vendor): JsonResponse {
        $vendor->update($request->validated());

        return $this->respondUpdated(
            new VendorResource($vendor),
            "Vendor updated successfully!"
        );
    }

    /**
     * Remove the specified vendor from storage.
     */
    public function destroy(Vendor $vendor): JsonResponse {
        $vendor->delete();

        return $this->respondSuccess("Vendor deleted successfully!");
    }
}
