<?php

namespace App\Http\Requests;

use App\Enums\BillStatus;
use App\Enums\PaymentMode;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class BillRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'sale_order_id' => ['required', 'exists:sale_orders,id'],
            'purchase_order_id' => ['required', 'exists:purchase_orders,id'],
            'customer_id' => ['required', 'exists:customers,id'],

            'invoice_number' => ['nullable', 'string', 'max:50'],
            'total_amount' => ['required', 'integer'],
            'is_direct' => ['required', 'boolean'],
            'status' => ['required', Rule::enum(BillStatus::class)],

            'mode' => ['required_if:status,'.BillStatus::PAID->value, Rule::enum(PaymentMode::class)],

            'items' => ["sometimes", 'array'],
            'items.*.id' => ["required_with:items", 'exists:items,id'],
            'items.*.quantity' => ["required_with:items", 'integer'],
            'items.*.amount' => ["required_with:items", 'integer'],
        ];

        if ($this->routeIs("bills.update")) {
            $rules["sale_order_id"][0] = "sometimes";
            $rules["purchase_order_id"][0] = "sometimes";
            $rules["customer_id"][0] = "sometimes";

            $rules["total_amount"][0] = "sometimes";
            $rules["is_direct"][0] = "sometimes";
            $rules["status"][0] = "sometimes";

            $rules["mode"][0] = "sometimes";

            $rules["items"][0] = "sometimes";
        }

        return $rules;
    }

    public function authorize(): bool {
        return true;
    }
}
