<?php

namespace App\Http\Requests;

use App\Enums\ItemType;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class ItemRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'factory_id' => ['nullable', 'exists:factories,id'],
            'shop_id' => ['nullable', 'exists:shops,id'],
            'name' => ['required', 'string', 'max:254'],
            'type' => ['required', Rule::enum(ItemType::class)],
            'stock_level' => ['required', 'integer'],
            'sku' => ['nullable', 'string', 'max:100'],
            'dimensions' => ['nullable', 'string', 'max:254'],
            'material_type' => ['nullable', 'string', 'max:254'],
            'unit_price' => ['required', 'integer'],
            'reorder_level' => ['required', 'integer'],
        ];

        if ($this->routeIs("items.update")) {
            $rules["name"][0] = 'sometimes';
            $rules["type"][0] = 'sometimes';
            $rules["stock_level"][0] = 'sometimes';
            $rules["unit_price"][0] = 'sometimes';
            $rules["reorder_level"][0] = 'sometimes';
        }

        return $rules;
    }

    public function authorize(): bool {
        return true;
    }
}
