<?php

namespace App\Http\Requests;

use App\Enums\JobCardStatus;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class JobCardRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'purchase_order_id' => ['required', 'exists:purchase_orders,id'],
            'description' => ['nullable', 'string'],
            'start_date' => ['required', 'date'],
            'end_date' => ['required', 'date'],
            'percentage_completed' => ['sometimes', 'integer'],
            'completed_quantity_count' => ['sometimes', 'integer'],
            'status' => ['required', Rule::enum(JobCardStatus::class)],

            'items' => ["required", 'array'],
            'items.*.id' => ["required_with:items", 'exists:items,id'],
            'items.*.quantity' => ["required_with:items", 'integer', 'min:1'],
        ];

        if ($this->routeIs("job-cards.update")) {
            $rules["purchase_order_id"][0] = "sometimes";
            $rules["start_date"][0] = "sometimes";
            $rules["end_date"][0] = "sometimes";
            $rules["status"][0] = "sometimes";

            $rules["items"][0] = "sometimes";
        }

        return $rules;
    }

    public function authorize(): bool {
        return true;
    }
}
