<?php

namespace App\Http\Requests;

use App\Enums\UserRole;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class UserRequest extends FormRequest
{
    public function authorize(): bool {
        return true;
    }

    public function rules(): array {
        $rules = [
            'factory_id' => ['nullable', 'exists:factories,id'],
            'shop_id' => ['nullable', 'exists:shops,id'],
            'name' => ['required', 'string', 'max:254'],
            'email' => [
                'required', 'email', 'max:254',
                Rule::unique("users")
            ],
            'mobile_no' => ['nullable', 'string', 'max:20'],
            'password' => ['required', 'string', "confirmed"],
            'role' => ['required', Rule::enum(UserRole::class)],
        ];

        if ($this->routeIs("users.update")) {
            $rules["name"][0] = "sometimes";
            $rules["email"][0] = "sometimes";
            $rules["email"][3] = Rule::unique("users")
                ->ignore($this->user()->id);
            $rules["password"][0] = "nullable";
            $rules["role"][0] = "sometimes";
        }

        return $rules;
    }

    /**
     * Override the validated method to exclude the password on update requests.
     * @param  null  $key
     * @param  null  $default
     */
    public function validated($key = null, $default = null) {
        $validatedData = parent::validated();

        // If it's an update request, exclude the password field if it's present
        if ($this->routeIs("users.update")) {
            unset($validatedData['password']);
        }

        return $validatedData;
    }
}
