<?php

namespace App\Http\Resources;

use App\Models\Bill;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

/** @mixin Bill */
class BillResource extends JsonResource
{
    public function toArray(Request $request): array {
        return [
            'id' => $this->id,

            'sale_order_id' => $this->sale_order_id,
            'purchase_order_id' => $this->purchase_order_id,
            'customer_id' => $this->customer_id,

            'invoice_number' => $this->invoice_number,
            'total_amount' => $this->total_amount,
            'is_direct' => $this->is_direct,
            'status' => $this->status,

            // relations
            'sale_order' => new SaleOrderResource($this->whenLoaded('saleOrder')),
            'purchase_order' => new PurchaseOrderResource($this->whenLoaded('purchaseOrder')),
            'customer' => new CustomerResource($this->whenLoaded('customer')),
            'items' => ItemResource::collection($this->whenLoaded('items')),
            'payment' => new PaymentResource($this->whenLoaded('payment')),

            // timestamps
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ];
    }
}
