<?php

namespace App\Http\Resources;

use App\Models\Item;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

/** @mixin Item */
class ItemResource extends JsonResource
{
    public function toArray(Request $request): array {
        return [
            'id' => $this->id,

            'factory_id' => $this->factory_id,
            'shop_id' => $this->shop_id,

            'name' => $this->name,
            'type' => $this->type,
            'stock_level' => $this->stock_level,
            'sku' => $this->sku,
            'dimensions' => $this->dimensions,
            'material_type' => $this->material_type,
            'unit_price' => $this->unit_price,
            'reorder_level' => $this->reorder_level,

            // relations
            'factory' => new FactoryResource($this->whenLoaded('factoryRelation')),
            'shop' => new ShopResource($this->whenLoaded('shop')),
            'purchase_order_item' => new ItemPurchaseOrderResource($this->whenPivotLoaded("item_purchase_order",
                $this->pivot)),
            'bill_item' => new BillItemResource($this->whenPivotLoaded("bill_item", $this->pivot)),
            'job_card_item' => new ItemJobCardResource($this->whenPivotLoaded("item_job_card", $this->pivot)),

            // timestamps
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ];
    }
}
