<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasOne;

class Bill extends Model
{
    use HasFactory, Filterable;

    public $filterFields = [
        'sale_order_id',
        'purchase_order_id',
        'customer_id',

        'invoice_number',
        'total_amount',
        'is_direct',
        'status',
    ];

    protected $fillable = [
        "sale_order_id",
        "purchase_order_id",
        "customer_id",

        "invoice_number",
        "total_amount",
        "is_direct",
        "status",
    ];

    public function saleOrder(): BelongsTo {
        return $this->belongsTo(SaleOrder::class);
    }

    public function purchaseOrder(): BelongsTo {
        return $this->belongsTo(PurchaseOrder::class);
    }

    public function customer(): BelongsTo {
        return $this->belongsTo(Customer::class);
    }

    public function items() {
        return $this->belongsToMany(Item::class)->using(BillItem::class)
            ->withPivot(["quantity", "amount"]);
    }

    public function payment(): HasOne {
        return $this->hasOne(Payment::class, 'bill_id');
    }

    protected function casts(): array {
        return [
            'is_direct' => 'boolean',
        ];
    }
}
