<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;

class JobCard extends Model
{
    use HasFactory, Filterable;

    public $filterFields = [
        'purchase_order_id',

        'start_date',
        'end_date',
        'percentage_completed',
        'completed_quantity_count',
        'status',
    ];

    protected $fillable = [
        'purchase_order_id',

        'description',
        'start_date',
        'end_date',
        'percentage_completed',
        'completed_quantity_count',
        'status',
    ];

    public function purchaseOrder(): BelongsTo {
        return $this->belongsTo(PurchaseOrder::class);
    }

    public function jobCardUpdates(): HasMany {
        return $this->hasMany(JobCardUpdate::class, 'job_card_id');
    }

    public function outsourcedJobs(): HasMany {
        return $this->hasMany(OutsourcedJob::class, 'job_card_id');
    }

    public function items(): BelongsToMany {
        return $this->belongsToMany(Item::class)->using(ItemJobCard::class)
            ->withPivot(["quantity"]);
    }
}
