<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasOne;

class PurchaseOrder extends Model
{
    use HasFactory, Filterable;

    protected $fillable = [
        'factory_id',
        'customer_id',

        'delivery_date',
        'total_amount',
    ];

    public function factoryRelation(): BelongsTo {
        return $this->belongsTo(Factory::class, 'factory_id');
    }

    public function customer(): BelongsTo {
        return $this->belongsTo(Customer::class);
    }

    public function items() {
        return $this->belongsToMany(Item::class)->using(ItemPurchaseOrder::class)
            ->withPivot(["quantity", "amount"]);
    }

    public function jobCard(): HasOne {
        return $this->hasOne(JobCard::class, 'purchase_order_id');
    }

    protected function casts(): array {
        return [
            'total_amount' => 'integer'
        ];
    }
}
