<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Model
{
    use HasFactory, Notifiable, HasApiTokens, Filterable;

    public $filterFields = [
        "factory_id",
        "shop_id",

        "name",
        "email",
        "role"
    ];

    protected $fillable = [
        "factory_id",
        "shop_id",

        'name',
        'email',
        'mobile_no',
        'password',
        'role',
        'last_login_at'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    // factory relation for factory_id column
    public function factoryRelation(): BelongsTo {
        return $this->belongsTo(Factory::class, 'factory_id');
    }

    public function shop(): BelongsTo {
        return $this->belongsTo(Shop::class);
    }

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array {
        return [
            'password' => 'hashed',
        ];
    }
}
