<?php

namespace Database\Factories;

use App\Enums\UserRole;
use Illuminate\Database\Eloquent\Factories\Factory;
use Illuminate\Support\Facades\Hash;

/**
 * @extends \Illuminate\Database\Eloquent\Factories\Factory<\App\Models\User>
 */
class UserFactory extends Factory
{
    /**
     * The current password being used by the factory.
     */
    protected static ?string $password;

    /**
     * Define the model's default state.
     *
     * @return array<string, mixed>
     */
    public function definition(): array {
        return [
            'name' => fake()->name(),
            'email' => fake()->unique()->safeEmail(),
            'mobile_no' => fake()->phoneNumber(),
            'email_verified_at' => now(),
            'password' => static::$password ??= Hash::make('password'),
        ];
    }

    /**
     * Indicate that the model's email address should be unverified.
     */
    public function unverified(): static {
        return $this->state(fn(array $attributes) => [
            'email_verified_at' => null,
        ]);
    }

    public function admin(): static {
        return $this->state(fn(array $attributes) => [
            'email' => 'admin@admin.com',
            'role' => UserRole::ADMIN->value,
        ]);
    }

    public function staff(): static {
        return $this->state(fn(array $attributes) => [
            'email' => 'staff@admin.com',
            'role' => UserRole::STAFF->value,
        ]);
    }

    public function factoryWorker(): static {
        return $this->state(fn(array $attributes) => [
            'email' => 'factory-worker@admin.com',
            'role' => UserRole::FACTORY_WORKER->value,
        ]);
    }
}
