<?php

namespace Database\Seeders;

use App\Enums\BillStatus;
use App\Enums\DeliveryStatus;
use App\Enums\JobCardStatus;
use App\Enums\PaymentMode;
use App\Models\Bill;
use App\Models\Customer;
use App\Models\Factory;
use App\Models\Item;
use App\Models\JobCard;
use App\Models\PurchaseOrder;
use App\Models\SaleOrder;
use App\Models\Shop;
use App\Models\User;
use App\Models\Vendor;
use Illuminate\Database\Seeder;

// use Illuminate\Database\Console\Seeds\WithoutModelEvents;

class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     */
    public function run(): void {
        $factory = Factory::factory()->create();
        $shop = Shop::factory()->create();

        // admin
        User::factory()->admin()->create([
            'factory_id' => $factory->id,
        ]);

        // staff
        User::factory()->staff()->create([
            'shop_id' => $shop->id,
        ]);

        // factory worker
        User::factory()->factoryWorker()->create([
            'factory_id' => $factory->id,
        ]);

        $item = Item::factory()->create([
            'factory_id' => $factory->id,
            'reorder_level' => 500
        ]);

        $vendor = Vendor::factory()->create();

        $customer = Customer::factory()->create();

        $itemQuantity = 8;

        $purchaseOrder = PurchaseOrder::factory()->create([
            'factory_id' => $factory->id,
            'customer_id' => $customer->id,
            'total_amount' => $item->unit_price * $itemQuantity,
        ]);

        $purchaseOrder->items()->attach($item->id,
            ["quantity" => $itemQuantity, "amount" => $item->unit_price]);

        $jobCard = JobCard::factory()->create([
            "purchase_order_id" => $purchaseOrder->id,
            'status' => JobCardStatus::IN_PROGRESS->value,
        ]);

        $jobCard->items()->attach($item->id, ["quantity" => $itemQuantity]);

        $jobCard->jobCardUpdates()->create([
            "percentage_completed" => 100,
            "completed_quantity_count" => (int) ($itemQuantity / 2)
        ]);

        $jobCard->jobCardUpdates()->create([
            "percentage_completed" => 100,
            "completed_quantity_count" => (int) ($itemQuantity / 2)
        ]);

        $jobCard->update([
            "percentage_completed" => 100,
            "completed_quantity_count" => $itemQuantity,
            'status' => JobCardStatus::COMPLETED->value,
        ]);

        $item->update([
            'stock_level' => $item->stock_level - $itemQuantity
        ]);

        $saleOrder = SaleOrder::factory()->create([
            "purchase_order_id" => $purchaseOrder->id,
            'delivery_status' => DeliveryStatus::PENDING->value,
        ]);

        $bill = Bill::factory()->create([
            'sale_order_id' => $saleOrder->id,
            "purchase_order_id" => $saleOrder->purchase_order_id,
            'customer_id' => $saleOrder->purchaseOrder->customer_id,

            'total_amount' => $saleOrder->purchaseOrder->total_amount,
            "status" => BillStatus::PENDING->value,
        ]);

        $bill->items()->attach($item->id, [
            "quantity" => $itemQuantity, "amount" => $item->unit_price
        ]);

        $bill->payment()->create([
            "is_credit" => true,
            "amount" => $bill->total_amount,
            "mode" => PaymentMode::CASH->value,
        ]);
    }
}
